@@ -218,7 +218,7 @@ void IdentityPage::slotRemoveIdentity()
     if (KMessageBox::warningContinueCancel(this,
                                            msg,
                                            i18np("Remove Identity", "Remove Identities", numberOfIdentity),
-                                           KGuiItem(i18n("&Remove"), QStringLiteral("edit-delete")))
+                                           KGuiItem(i18nc("@action:button", "&Remove"), QStringLiteral("edit-delete")))
         == KMessageBox::Continue) {
         for (QTreeWidgetItem *selecteditem : selectedItems) {
             auto identityItem = dynamic_cast<IdentityListViewItem *>(selecteditem);
@@ -269,16 +269,16 @@ void IdentityPage::slotRenameIdentityFromItem(KMail::IdentityListViewItem *item,
 void IdentityPage::slotContextMenu(IdentityListViewItem *item, const QPoint &pos)
 {
     QMenu menu(this);
-    menu.addAction(QIcon::fromTheme(QStringLiteral("list-add")), i18n("Add..."), this, &IdentityPage::slotNewIdentity);
+    menu.addAction(QIcon::fromTheme(QStringLiteral("list-add")), i18nc("@action", "Add…"), this, &IdentityPage::slotNewIdentity);
     if (item) {
-        menu.addAction(QIcon::fromTheme(QStringLiteral("document-edit")), i18n("Modify..."), this, &IdentityPage::slotModifyIdentity);
-        menu.addAction(QIcon::fromTheme(QStringLiteral("edit-rename")), i18n("Rename"), this, &IdentityPage::slotRenameIdentity);
+        menu.addAction(QIcon::fromTheme(QStringLiteral("document-edit")), i18nc("@action", "Modify…"), this, &IdentityPage::slotModifyIdentity);
+        menu.addAction(QIcon::fromTheme(QStringLiteral("edit-rename")), i18nc("@action", "Rename"), this, &IdentityPage::slotRenameIdentity);
         if (mIPage.mIdentityList->topLevelItemCount() > 1) {
-            menu.addAction(QIcon::fromTheme(QStringLiteral("list-remove")), i18n("Remove"), this, &IdentityPage::slotRemoveIdentity);
+            menu.addAction(QIcon::fromTheme(QStringLiteral("list-remove")), i18nc("@action", "Remove"), this, &IdentityPage::slotRemoveIdentity);
         }
         if (!item->identity().isDefault()) {
             menu.addSeparator();
-            menu.addAction(i18n("Set as Default"), this, &IdentityPage::slotSetAsDefault);
+            menu.addAction(i18nc("@action", "Set as Default"), this, &IdentityPage::slotSetAsDefault);
         }
     }
     menu.exec(pos);
