@@ -409,8 +409,9 @@ KMCommand::Result KMMailtoComposeCommand::execute()
     }
 
     MessageHelper::initHeader(msg, KMKernel::self()->identityManager(), id);
-    msg->contentType()->setCharset("utf-8");
-    msg->to()->fromUnicodeString(KEmailAddress::decodeMailtoUrl(mUrl), "utf-8");
+    // Already defined in MessageHelper::initHeader
+    msg->contentType(false)->setCharset(QByteArrayLiteral("utf-8"));
+    msg->to()->fromUnicodeString(KEmailAddress::decodeMailtoUrl(mUrl));
 
     KMail::Composer *win = KMail::makeComposer(msg, false, false, KMail::Composer::New, id);
     win->setFocusToSubject();
@@ -592,11 +593,6 @@ KMCommand::Result KMEditItemCommand::execute()
         return Failed;
     }
 
-    if (mDeleteFromSource) {
-        setDeletesItself(true);
-        auto job = new Akonadi::ItemDeleteJob(item);
-        connect(job, &KIO::Job::result, this, &KMEditItemCommand::slotDeleteItem);
-    }
     KMail::Composer *win = KMail::makeComposer();
     bool lastEncrypt = false;
     bool lastSign = false;
@@ -623,8 +619,14 @@ KMCommand::Result KMEditItemCommand::execute()
         win->setFcc(QString::number(sentAttribute->moveToCollection().id()));
     }
     win->show();
+
     if (mDeleteFromSource) {
         win->setModified(true);
+
+        setDeletesItself(true);
+        setEmitsCompletedItself(true);
+        auto job = new Akonadi::ItemDeleteJob(item);
+        connect(job, &KIO::Job::result, this, &KMEditItemCommand::slotDeleteItem);
     }
 
     return OK;
@@ -923,8 +925,8 @@ KMCommand::Result KMForwardCommand::execute()
                                                                 "attachments in one message (as a MIME digest) or as "
                                                                 "individual messages?"),
                                                            QString(),
-                                                           KGuiItem(i18n("Send As Digest")),
-                                                           KGuiItem(i18n("Send Individually")));
+                                                           KGuiItem(i18nc("@action:button", "Send As Digest")),
+                                                           KGuiItem(i18nc("@action:button", "Send Individually")));
 
         if (answer == KMessageBox::ButtonCode::PrimaryAction) {
             Akonadi::Item firstItem(msgList.first());
@@ -1909,7 +1911,8 @@ KMCommand::Result KMShareImageCommand::execute()
     uint id = 0;
 
     MessageHelper::initHeader(msg, KMKernel::self()->identityManager(), id);
-    msg->contentType()->setCharset("utf-8");
+    // Already defined in MessageHelper::initHeader
+    msg->contentType(false)->setCharset(QByteArrayLiteral("utf-8"));
 
     KMail::Composer *win = KMail::makeComposer(msg, false, false, KMail::Composer::New, id);
     win->setFocusToSubject();
