@@ -20,7 +20,6 @@ using namespace Qt::Literals::StringLiterals;
 #include <MessageCore/StringUtil>
 #include <MessageViewer/HeaderStylePlugin>
 #include <MessageViewer/MessageViewerSettings>
-#include <PimCommonAkonadi/AnnotationDialog>
 
 #include <Akonadi/ChangeRecorder>
 #include <Akonadi/ItemFetchJob>
@@ -48,7 +47,6 @@ using namespace Qt::Literals::StringLiterals;
 
 #include "folderarchive/folderarchivemanager.h"
 #include <Akonadi/Collection>
-#include <Akonadi/EntityAnnotationsAttribute>
 #include <Akonadi/StandardMailActionManager>
 #include <MailCommon/MailUtil>
 #include <MessageViewer/MessageViewerUtil>
@@ -61,28 +59,26 @@ MessageActions::MessageActions(KActionCollection *ac, QWidget *parent)
     : QObject(parent)
     , mParent(parent)
     , mReplyActionMenu(new KActionMenu(QIcon::fromTheme(QStringLiteral("mail-reply-sender")), i18nc("Message->", "&Reply"), this))
-    , mReplyAction(new QAction(QIcon::fromTheme(QStringLiteral("mail-reply-sender")), i18n("&Reply..."), this))
-    , mReplyAllAction(new QAction(QIcon::fromTheme(QStringLiteral("mail-reply-all")), i18n("Reply to &All..."), this))
-    , mReplyAuthorAction(new QAction(QIcon::fromTheme(QStringLiteral("mail-reply-sender")), i18n("Reply to A&uthor..."), this))
-    , mReplyListAction(new QAction(QIcon::fromTheme(QStringLiteral("mail-reply-list")), i18n("Reply to Mailing-&List..."), this))
-    , mNoQuoteReplyAction(new QAction(i18n("Reply Without &Quote..."), this))
-    , mForwardInlineAction(new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")), i18nc("@action:inmenu Message->Forward->", "&Inline..."), this))
-    , mForwardAttachedAction(
-          new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")), i18nc("@action:inmenu Message->Forward->", "As &Attachment..."), this))
-    , mRedirectAction(new QAction(i18nc("Message->Forward->", "&Redirect..."), this))
-    , mNewToRecipientsAction(new QAction(i18n("New Message to Recipients..."), this))
+    , mReplyAction(new QAction(QIcon::fromTheme(QStringLiteral("mail-reply-sender")), i18n("&Reply…"), this))
+    , mReplyAllAction(new QAction(QIcon::fromTheme(QStringLiteral("mail-reply-all")), i18n("Reply to &All…"), this))
+    , mReplyAuthorAction(new QAction(QIcon::fromTheme(QStringLiteral("mail-reply-sender")), i18n("Reply to A&uthor…"), this))
+    , mReplyListAction(new QAction(QIcon::fromTheme(QStringLiteral("mail-reply-list")), i18n("Reply to Mailing-&List…"), this))
+    , mNoQuoteReplyAction(new QAction(i18nc("@action", "Reply Without &Quote…"), this))
+    , mForwardInlineAction(new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")), i18nc("@action:inmenu Message->Forward->", "&Inline…"), this))
+    , mForwardAttachedAction(new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")), i18nc("@action:inmenu Message->Forward->", "As &Attachment…"), this))
+    , mRedirectAction(new QAction(i18nc("Message->Forward->", "&Redirect…"), this))
+    , mNewToRecipientsAction(new QAction(i18nc("@action", "New Message to Recipients…"), this))
     , mStatusMenu(new KActionMenu(i18n("Mar&k Message"), this))
     , mForwardActionMenu(new KActionMenu(QIcon::fromTheme(QStringLiteral("mail-forward")), i18nc("Message->", "&Forward"), this))
     , mMailingListActionMenu(new KActionMenu(QIcon::fromTheme(QStringLiteral("mail-message-new-list")), i18nc("Message->", "Mailing-&List"), this))
-    , mAnnotateAction(new QAction(QIcon::fromTheme(QStringLiteral("view-pim-notes")), i18n("Add Note..."), this))
     , mEditAsNewAction(new QAction(QIcon::fromTheme(QStringLiteral("document-edit")), i18n("&Edit As New"), this))
-    , mListFilterAction(new QAction(i18n("Filter on Mailing-&List..."), this))
-    , mAddFollowupReminderAction(new QAction(i18n("Add Followup Reminder..."), this))
-    , mDebugAkonadiSearchAction(new QAction(QStringLiteral("Debug Akonadi Search..."), this)) /* dont translate it*/
-    , mSendAgainAction(new QAction(i18n("Send A&gain..."), this))
+    , mListFilterAction(new QAction(i18nc("@action", "Filter on Mailing-&List…"), this))
+    , mAddFollowupReminderAction(new QAction(i18nc("@action", "Add Followup Reminder…"), this))
+    , mDebugAkonadiSearchAction(new QAction(QStringLiteral("Debug Akonadi Search…"), this)) /* dont translate it*/
+    , mSendAgainAction(new QAction(i18nc("@action", "Send A&gain…"), this))
     , mNewMessageFromTemplateAction(new QAction(QIcon::fromTheme(QStringLiteral("document-new")), i18n("New Message From &Template"), this))
     , mWebShortcutMenuManager(new KIO::KUriFilterSearchProviderActions(this))
-    , mExportToPdfAction(new QAction(QIcon::fromTheme(QStringLiteral("application-pdf")), i18n("Export to PDF..."), this))
+    , mExportToPdfAction(new QAction(QIcon::fromTheme(QStringLiteral("application-pdf")), i18n("Export to PDF…"), this))
     , mArchiveMessageAction(new QAction(i18nc("@action:inmenu", "Archive Message"), this))
 
 {
@@ -119,9 +115,6 @@ MessageActions::MessageActions(KActionCollection *ac, QWidget *parent)
 
     ac->addAction(QStringLiteral("set_status"), mStatusMenu);
 
-    ac->addAction(QStringLiteral("annotate"), mAnnotateAction);
-    connect(mAnnotateAction, &QAction::triggered, this, &MessageActions::annotateMessage);
-
     ac->addAction(QStringLiteral("editasnew"), mEditAsNewAction);
     connect(mEditAsNewAction, &QAction::triggered, this, &MessageActions::editCurrentMessage);
     ac->setDefaultShortcut(mEditAsNewAction, Qt::Key_T);
@@ -292,11 +285,6 @@ KActionMenu *MessageActions::forwardMenu() const
     return mForwardActionMenu;
 }
 
-QAction *MessageActions::annotateAction() const
-{
-    return mAnnotateAction;
-}
-
 QAction *MessageActions::printAction() const
 {
     return mPrintAction;
@@ -366,14 +354,6 @@ void MessageActions::updateActions()
     mNoQuoteReplyAction->setEnabled(hasPayload);
     mSendAgainAction->setEnabled(hasPayload);
 
-    mAnnotateAction->setEnabled(uniqItem);
-    mAddFollowupReminderAction->setEnabled(uniqItem);
-    if (!mCurrentItem.hasAttribute<Akonadi::EntityAnnotationsAttribute>()) {
-        mAnnotateAction->setText(i18n("Add Note..."));
-    } else {
-        mAnnotateAction->setText(i18n("Edit Note..."));
-    }
-
     mStatusMenu->setEnabled(multiVisible);
 
     mPrintAction->setEnabled(mMessageView != nullptr);
@@ -387,7 +367,6 @@ void MessageActions::updateActions()
             job->fetchScope().fetchAllAttributes();
             job->fetchScope().fetchFullPayload(true);
             job->fetchScope().fetchPayloadPart(Akonadi::MessagePart::Header);
-            job->fetchScope().fetchAttribute<Akonadi::EntityAnnotationsAttribute>();
             connect(job, &Akonadi::ItemFetchJob::result, this, &MessageActions::slotUpdateActionsFetchDone);
         }
     }
@@ -416,7 +395,7 @@ void MessageActions::clearMailingListActions()
 {
     mMailingListActionMenu->setEnabled(false);
     mListFilterAction->setEnabled(false);
-    mListFilterAction->setText(i18n("Filter on Mailing-List..."));
+    mListFilterAction->setText(i18n("Filter on Mailing-List…"));
 }
 
 void MessageActions::updateMailingListActions(const Akonadi::Item &messageItem)
@@ -482,7 +461,7 @@ void MessageActions::updateMailingListActions(const Akonadi::Item &messageItem)
         const QString lname = MailingList::name(message, name, value);
         if (!lname.isEmpty()) {
             mListFilterAction->setEnabled(true);
-            mListFilterAction->setText(i18n("Filter on Mailing-List %1...", lname));
+            mListFilterAction->setText(i18n("Filter on Mailing-List %1…", lname));
         }
     }
 }
@@ -698,17 +677,6 @@ void MessageActions::editCurrentMessage()
     }
 }
 
-void MessageActions::annotateMessage()
-{
-    if (!mCurrentItem.isValid()) {
-        return;
-    }
-
-    auto dialog = new PimCommon::AnnotationEditDialog(mCurrentItem, mParent);
-    dialog->exec();
-    delete dialog;
-}
-
 void MessageActions::addWebShortcutsMenu(QMenu *menu, const QString &text)
 {
     mWebShortcutMenuManager->setSelectedText(text);
@@ -740,7 +708,7 @@ void MessageActions::slotDebugAkonadiSearch()
 
 void MessageActions::slotResendMessage()
 {
-    // mCurrentItem.isValid() may be false here if message was imported via 'File' -> 'Open...'
+    // mCurrentItem.isValid() may be false here if message was imported via 'File' -> 'Open…'
     KMCommand *command = new KMResendMessageCommand(mParent, mCurrentItem);
     command->start();
 }
